@@ -1,7 +1,12 @@
 print.summary.rm5 <- function(x, ...){
   
-  if (!inherits(x, "summary.rm5"))
-    stop("Argument 'object' must be an object of class \"summary.rm5\"")
+  ##
+  ##
+  ## (1) Check for summary.rm5 object
+  ##
+  ##
+  chkclass(x, "summary.rm5")
+  
   
   n <- 1
   for (i in 1:length(x)){
@@ -11,5 +16,6 @@ print.summary.rm5 <- function(x, ...){
     n <- n+1
   }
   
+  
   invisible(NULL)
 }
